Documentation
¶
Index ¶
- Constants
- func Debug(args ...interface{})
- func Debugf(format string, args ...interface{})
- func Debugln(args ...interface{})
- func Error(args ...interface{})
- func Errorf(format string, args ...interface{})
- func Errorln(args ...interface{})
- func Fatal(args ...interface{})
- func Fatalf(format string, args ...interface{})
- func Fatalln(args ...interface{})
- func Info(args ...interface{})
- func Infof(format string, args ...interface{})
- func Infoln(args ...interface{})
- func Panic(args ...interface{})
- func Panicf(format string, args ...interface{})
- func Panicln(args ...interface{})
- func Print(args ...interface{})
- func Printf(format string, args ...interface{})
- func Println(args ...interface{})
- func SetupGlobalLogger(logger Logger)
- func Warn(args ...interface{})
- func Warnf(format string, args ...interface{})
- func Warning(args ...interface{})
- func Warningf(format string, args ...interface{})
- func Warningln(args ...interface{})
- func Warnln(args ...interface{})
- type Base
- type Level
- type Logger
- type Options
- type StdLogger
Constants ¶
const ( TextFormat = "text" JsonFormat = "json" )
Variables ¶
This section is empty.
Functions ¶
func Debugf ¶
func Debugf(format string, args ...interface{})
Debugf logs a debug message with formatting.
func Debugln ¶ added in v1.7.7
func Debugln(args ...interface{})
Debugln logs a debug message with a line break.
func Errorf ¶
func Errorf(format string, args ...interface{})
Errorf logs an error message with formatting.
func Errorln ¶ added in v1.7.7
func Errorln(args ...interface{})
Errorln logs an error message with a line break.
func Fatalf ¶
func Fatalf(format string, args ...interface{})
Fatalf logs a fatal message with formatting.
func Fatalln ¶ added in v1.7.7
func Fatalln(args ...interface{})
Fatalln logs a fatal message with a line break.
func Infof ¶
func Infof(format string, args ...interface{})
Infof logs an info message with formatting.
func Infoln ¶ added in v1.7.7
func Infoln(args ...interface{})
Infoln logs an info message with a line break.
func Panicf ¶
func Panicf(format string, args ...interface{})
Panicf logs a panic message with formatting.
func Panicln ¶ added in v1.7.7
func Panicln(args ...interface{})
Panicln logs a panic message with a line break.
func Printf ¶ added in v1.7.7
func Printf(format string, args ...interface{})
Printf logs a message with formatting.
func Println ¶ added in v1.7.7
func Println(args ...interface{})
Println logs a message with a line break.
func SetupGlobalLogger ¶
func SetupGlobalLogger(logger Logger)
func Warnf ¶
func Warnf(format string, args ...interface{})
Warnf logs a warning message with formatting.
func Warningf ¶ added in v1.7.7
func Warningf(format string, args ...interface{})
Warningf logs a warning message with formatting.
Types ¶
type Base ¶ added in v1.7.9
type Base interface {
Debugf(format string, args ...interface{})
Infof(format string, args ...interface{})
Printf(format string, args ...interface{})
Warnf(format string, args ...interface{})
Warningf(format string, args ...interface{})
Errorf(format string, args ...interface{})
Fatalf(format string, args ...interface{})
Panicf(format string, args ...interface{})
Debug(args ...interface{})
Info(args ...interface{})
Print(args ...interface{})
Warn(args ...interface{})
Warning(args ...interface{})
Error(args ...interface{})
Fatal(args ...interface{})
Panic(args ...interface{})
Debugln(args ...interface{})
Infoln(args ...interface{})
Println(args ...interface{})
Warnln(args ...interface{})
Warningln(args ...interface{})
Errorln(args ...interface{})
Fatalln(args ...interface{})
Panicln(args ...interface{})
}
type Logger ¶
Click to show internal directories.
Click to hide internal directories.